==> xlniuxdata-vipgame-1.1.2-20190423.093155-5-sources.jar: com/xunlei/niux/data/vipgame/vo/UserLastLoginInfo.java <==
package com.xunlei.niux.data.vipgame.vo;


import java.io.Serializable;


public class UserLastLoginInfo implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * key_id
     */
    private String key_id;

    /**
     * uid
     */
    private String uid;

    /**
     * gameid
     */
    private String gameid;

    /**
     * svrname
     */
    private String svrname;

    /**
     * svrid
     */
    private String svrid;

    /**
     * svruid
     */
    private String svruid;

    /**
     * role
     */
    private String role;

    /**
     * regionid
     */
    private String regionid;

    /**
     * lasttime
     */
    private String lasttime;

    /**
     * firsttime
     */
    private String firsttime;

    /**
     * source
     */
    private String source;

    /**
     * times
     */
    private Integer times;



    public String getkey_id() {
        return key_id;
    }

    public void setkey_id(String key_id) {
        this.key_id = key_id;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public String getGameid() {
        return gameid;
    }

    public void setGameid(String gameid) {
        this.gameid = gameid;
    }

    public String getSvrname() {
        return svrname;
    }

    public void setSvrname(String svrname) {
        this.svrname = svrname;
    }

    public String getSvrid() {
        return svrid;
    }

    public void setSvrid(String svrid) {
        this.svrid = svrid;
    }

    public String getSvruid() {
        return svruid;
    }

    public void setSvruid(String svruid) {
        this.svruid = svruid;
    }

    public String getRole() {
        return role;
    }

    public void setRole(String role) {
        this.role = role;
    }

    public String getRegionid() {
        return regionid;
    }

    public void setRegionid(String regionid) {
        this.regionid = regionid;
    }

    public String getLasttime() {
        return lasttime;
    }

    public void setLasttime(String lasttime) {
        this.lasttime = lasttime;
    }

    public String getFirsttime() {
        return firsttime;
    }

    public void setFirsttime(String firsttime) {
        this.firsttime = firsttime;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public Integer getTimes() {
        return times;
    }

    public void setTimes(Integer times) {
        this.times = times;
    }
    @Override
    public String toString() {
        return uid+"|"+firsttime+"|"+lasttime;
    }
}

==> xlniuxdata-vipgame-1.1.5-20190424.020857-2-sources.jar: com/xunlei/niux/data/vipgame/vo/UserLastLoginInfo.java <==
package com.xunlei.niux.data.vipgame.vo;


import java.io.Serializable;
import java.util.Date;


public class UserLastLoginInfo implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * key_id
     */
    private String key_id;

    /**
     * uid
     */
    private String uid;

    /**
     * gameid
     */
    private String gameid;

    /**
     * svrname
     */
    private String svrname;

    /**
     * svrid
     */
    private String svrid;

    /**
     * svruid
     */
    private String svruid;

    /**
     * role
     */
    private String role;

    /**
     * regionid
     */
    private String regionid;

    /**
     * lasttime
     */
    private Date lasttime;

    /**
     * firsttime
     */
    private Date firsttime;

    /**
     * source
     */
    private String source;

    /**
     * times
     */
    private Integer times;



    public String getkey_id() {
        return key_id;
    }

    public void setkey_id(String key_id) {
        this.key_id = key_id;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public String getGameid() {
        return gameid;
    }

    public void setGameid(String gameid) {
        this.gameid = gameid;
    }

    public String getSvrname() {
        return svrname;
    }

    public void setSvrname(String svrname) {
        this.svrname = svrname;
    }

    public String getSvrid() {
        return svrid;
    }

    public void setSvrid(String svrid) {
        this.svrid = svrid;
    }

    public String getSvruid() {
        return svruid;
    }

    public void setSvruid(String svruid) {
        this.svruid = svruid;
    }

    public String getRole() {
        return role;
    }

    public void setRole(String role) {
        this.role = role;
    }

    public String getRegionid() {
        return regionid;
    }

    public void setRegionid(String regionid) {
        this.regionid = regionid;
    }

    public String getKey_id() {
        return key_id;
    }

    public void setKey_id(String key_id) {
        this.key_id = key_id;
    }

    public Date getLasttime() {
        return lasttime;
    }

    public void setLasttime(Date lasttime) {
        this.lasttime = lasttime;
    }

    public Date getFirsttime() {
        return firsttime;
    }

    public void setFirsttime(Date firsttime) {
        this.firsttime = firsttime;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public Integer getTimes() {
        return times;
    }

    public void setTimes(Integer times) {
        this.times = times;
    }
    @Override
    public String toString() {
        return uid+"|"+firsttime+"|"+lasttime;
    }
}
